@@ -2,7 +2,7 @@ package Web::ComposableRequest;
 
 use 5.010001;
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.17.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.18.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
 use Scalar::Util                      qw( blessed );
 use Web::ComposableRequest::Base;
@@ -64,7 +64,7 @@ has 'request_class' => is => 'lazy', isa => NonEmptySimpleStr,
 
 # Public methods
 sub new_from_simple_request {
-   my ($self, $opts, @args) = @_; my $attr = { %{ $opts // {} } };
+   my ($self, $opts, @args) = @_; my $attr = { %{ $opts // {} } }; my $query;
 
    my $request_class = $self->request_class; # Trigger role application
 
@@ -72,6 +72,9 @@ sub new_from_simple_request {
    @args and is_hashref $args[ -1 ] and $attr->{env   } = pop @args;
    @args and is_hashref $args[ -1 ] and $attr->{params} = pop @args;
 
+   $query = $attr->{env}->{ 'Web::Dispatch::ParamParser.unpacked_query' }
+      and $attr->{params} = $query;
+
    if ((@args and blessed $args[ 0 ])) { $attr->{upload} = $args[ 0 ] }
    else {
       for my $arg (grep { defined && length } @args) {
