@@ -139,7 +139,7 @@ has '_content' => is => 'lazy', isa => Str,
    builder     => $_build__content;
 
 has '_env'     => is => 'ro',   isa => HashRef,
-   builder     => sub { {} }, init_arg => 'env';
+   init_arg    => 'env', required => TRUE;
 
 has '_log'     => is => 'lazy', isa => CodeRef,
    builder     => sub { $_[ 0 ]->_env->{ 'psgix.logger' } // sub {} },
@@ -230,8 +230,9 @@ my $_scrub_hash = sub {
       my $v = delete $hash->{ $k };
 
       $hash->{ $_scrub_value->( 'key', $k, $opts ) }
-         = (is_arrayref $v)
-         ? [ map { $_scrub_value->( $k, $_, $opts ) } @{ $v } ]
+         = (is_arrayref $v && $opts->{multiple}) ?
+            [ map { $_scrub_value->( $k, $_, $opts ) } @{ $v } ]
+         : (is_arrayref $v) ? $_get_last_value->( $k, $v, $opts )
          : $_scrub_value->( $k, $v, $opts );
    }
 
